@@ -410,6 +410,7 @@ class FPDFRB(fpdf.FPDF):
             helvetica=dict(standard_font=True),
             times=dict(standard_font=True))
         self.add_font('DejaVu', '', './reportbro_plus/fonts/DejaVuSansCondensed.ttf', uni=True)
+        self.add_font('DejaVu', 'B', './reportbro_plus/fonts/DejaVuSansCondensed-Bold.ttf', uni=True)
 
         if additional_fonts:
             for additional_font in additional_fonts:
@@ -488,7 +489,7 @@ class FPDFRB(fpdf.FPDF):
             if underline:
                 style += 'U'
             fpdf.FPDF.set_font(self, family, style, size)
-            fpdf.FPDF.set_font(self, 'DejaVu', '', 14)
+            fpdf.FPDF.set_font(self, 'DejaVu', style, size)
             return True
         else:
             return False
